=======================
Simple Gaussian example
=======================

This page show a complete example of running ``nessai`` including setting up the logger, defining a model, configuring the sampler and finally running the sampler. The code for this example is included in `example directory <https://github.com/mj-will/nessai/tree/master/examples>`_.

Code
====

.. literalinclude:: ../examples/2d_gaussian.py
    :language: python

Output
======

In this examples the sampler with save the outputs to ``outdir/2d_examples/``.
For an explanation of the outputs see :ref:`understanding the outputs`.
